==> package-search-223.7571.182-sources.jar: com/jetbrains/packagesearch/intellij/plugin/ui/toolwindow/models/DependencyUsageInfo.kt <==
/*******************************************************************************
 * Copyright 2000-2022 JetBrains s.r.o. and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models

import com.jetbrains.packagesearch.intellij.plugin.extensibility.DependencyDeclarationIndexes
import com.jetbrains.packagesearch.intellij.plugin.extensibility.ProjectModule
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageVersion.Missing

internal data class DependencyUsageInfo(
    val projectModule: ProjectModule,
    val declaredVersion: PackageVersion,
    val resolvedVersion: PackageVersion,
    val scope: PackageScope,
    val userDefinedScopes: List<PackageScope>,
    val declarationIndexInBuildFile: DependencyDeclarationIndexes?
) {

    fun getDeclaredVersionOrFallback() = if (declaredVersion !is Missing) declaredVersion else resolvedVersion
}

==> package-search-231.8770.65-sources.jar: com/jetbrains/packagesearch/intellij/plugin/ui/toolwindow/models/DependencyUsageInfo.kt <==
/*******************************************************************************
 * Copyright 2000-2022 JetBrains s.r.o. and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models

import com.jetbrains.packagesearch.intellij.plugin.extensibility.DependencyDeclarationIndexes
import com.jetbrains.packagesearch.intellij.plugin.extensibility.PackageSearchModule
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.versions.NormalizedPackageVersion

internal data class DependencyUsageInfo(
    val module: PackageSearchModule,
    val declaredVersion: NormalizedPackageVersion<*>,
    val resolvedVersion: NormalizedPackageVersion<*>,
    val scope: PackageScope,
    val userDefinedScopes: List<PackageScope>,
    val declarationIndexInBuildFile: DependencyDeclarationIndexes?
) {

    fun getDeclaredVersionOrFallback() = if (declaredVersion !is NormalizedPackageVersion.Missing) declaredVersion else resolvedVersion
}
